@@ -6,7 +6,7 @@ use 5.016;
 use warnings;
 use utf8;
 
-our $VERSION = 1.001;
+our $VERSION = 1.002;
 
 use Exporter qw(import);
 use IO::Uncompress::Unzip;
@@ -281,7 +281,7 @@ Mail::Exim::ACL::Attachments - Reject email attachments
 
 =head1 VERSION
 
-version 1.001
+version 1.002
 
 =head1 SYNOPSIS
 
@@ -304,9 +304,9 @@ version 1.001
 
 =head1 DESCRIPTION
 
-A Perl module for the L<Exim|https://www.exim.org/> mailer that checks email
-attachments for blocked filenames.  Common executable, macro-enabled and
-archive file formats are identified.
+A Perl module for the Exim mailer that checks email attachments for blocked
+filenames.  Common executable, macro-enabled and archive file formats are
+identified.
 
 The list of blocked filename extensions is built from information published by
 Microsoft and Wikipedia.
